@@ -152,10 +152,19 @@ sub render {
 	    $x += $fragment->{width};
 	    if ( length($fragment->{label}) ) {
 		my $pdf = $text->{' api'};
-		my $x = ref($pdf) . '::NamedDestination';
-		my $dest = $x->new($pdf);
-		$dest->goto( $text->{' apipage'}, xyz => (undef,undef,undef) );
-		$pdf->named_destination( 'Dests', $fragment->{label}, $dest );
+		my $page = $text->{' apipage'};
+		my $target = $fragment->{label};
+
+		# Augmented API for apps that keep track of bookmarks.
+		my $c = $pdf->can("named_dest_fiddle");
+		$target = $pdf->$c($target) if $c;
+		$c = $pdf->can("named_dest_register");
+		$pdf->$c( $target, $page );
+
+		$c = ref($pdf) . '::NamedDestination';
+		my $dest = $c->new($pdf);
+		$dest->goto( $page, xyz => (undef,undef,undef) );
+		$pdf->named_destination( 'Dests', $target, $dest );
 	    }
 	}
 
@@ -311,8 +320,15 @@ sub render {
 	    my $sz = $fragment->{size} || $self->{_currentsize};
 	    my $ann = $text->{' apipage'}->annotation;
 	    my $target = $fragment->{href};
+
 	    if ( $target =~ /^#(.+)/ ) { # named destination
-		$ann->link($1);
+		# Augmented API for apps that keep track of bookmarks.
+		my $pdf = $text->{' api'};
+		if ( my $c = $pdf->can("named_dest_fiddle") ) {
+		    $target = $pdf->$c($1);
+		}
+
+		$ann->link($target);
 	    }
 	    else {
 		$ann->uri($target);
